import{c as i,j as e}from"./index-qMrAuFFG.js";import{c as r,l as d,C as o}from"./queries-B0q6a4VE.js";/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const u=[["path",{d:"m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3",key:"wmoenq"}],["path",{d:"M12 9v4",key:"juzpu7"}],["path",{d:"M12 17h.01",key:"p32p05"}]],g=i("TriangleAlert",u),m=d("relative w-full rounded-lg border px-4 py-3 text-sm grid has-[>svg]:grid-cols-[calc(var(--spacing)*4)_1fr] grid-cols-[0_1fr] has-[>svg]:gap-x-3 gap-y-0.5 items-start [&>svg]:size-4 [&>svg]:translate-y-0.5 [&>svg]:text-current",{variants:{variant:{default:"bg-card text-card-foreground",destructive:"text-destructive bg-card [&>svg]:text-current *:data-[slot=alert-description]:text-destructive/90"}},defaultVariants:{variant:"default"}});function x({className:a,variant:t,...s}){return e.jsx("div",{"data-slot":"alert",role:"alert",className:r(m({variant:t}),a),...s})}function v({className:a,...t}){return e.jsx("div",{"data-slot":"alert-title",className:r("col-start-2 line-clamp-1 min-h-4 font-medium tracking-tight",a),...t})}function p({className:a,...t}){return e.jsx("div",{"data-slot":"alert-description",className:r("text-muted-foreground col-start-2 grid justify-items-start gap-1 text-sm [&_p]:leading-relaxed break-all",a),...t})}function A({content:a,title:t,type:s="error",className:l,icon:n}){const c=n??(s==="warning"?e.jsx(g,{className:"h-4 w-4"}):e.jsx(o,{className:"h-4 w-4"}));return e.jsxs(x,{variant:"destructive",className:r(l),children:[c,t&&e.jsx(v,{children:t}),e.jsx(p,{className:t?void 0:"text-sm",children:a})]})}export{A,g as T};
