import{c as oe,r as s,j as a}from"./index-qMrAuFFG.js";import{g as ge,h as ct,i as we,j as _e,u as Ce,k as ut,R as it,A as dt,l as Y,m as lt,n as F,o as M,p as pt,q as ft,r as T,s as mt,t as vt,v as Mt,w as ht,F as xt,D as gt,x as wt,C as _t,y as Ct,z as Re,E as Rt,G as he}from"./loading-PETOxw4W.js";import{c as y}from"./queries-B0q6a4VE.js";/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const bt=[["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}],["circle",{cx:"19",cy:"12",r:"1",key:"1wjl8i"}],["circle",{cx:"5",cy:"12",r:"1",key:"1pcz8c"}]],Wn=oe("Ellipsis",bt);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const yt=[["path",{d:"M5 12h14",key:"1ays0h"}],["path",{d:"M12 5v14",key:"s699le"}]],qn=oe("Plus",yt);/**
 * @license lucide-react v0.476.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Et=[["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6",key:"4alrt4"}],["path",{d:"M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2",key:"v07s0e"}],["line",{x1:"10",x2:"10",y1:"11",y2:"17",key:"1uufr5"}],["line",{x1:"14",x2:"14",y1:"11",y2:"17",key:"xtxkd"}]],Zn=oe("Trash2",Et);var ne=["Enter"," "],Dt=["ArrowDown","PageUp","Home"],be=["ArrowUp","PageDown","End"],Pt=[...Dt,...be],It={ltr:[...ne,"ArrowRight"],rtl:[...ne,"ArrowLeft"]},St={ltr:["ArrowLeft"],rtl:["ArrowRight"]},G="Menu",[k,Nt,Tt]=ct(G),[D,ye]=ge(G,[Tt,we,_e]),W=we(),Ee=_e(),[At,P]=D(G),[jt,K]=D(G),De=e=>{const{__scopeMenu:t,open:n=!1,children:o,dir:r,onOpenChange:c,modal:i=!0}=e,l=W(t),[m,v]=s.useState(null),p=s.useRef(!1),u=Ce(c),f=ut(r);return s.useEffect(()=>{const x=()=>{p.current=!0,document.addEventListener("pointerdown",h,{capture:!0,once:!0}),document.addEventListener("pointermove",h,{capture:!0,once:!0})},h=()=>p.current=!1;return document.addEventListener("keydown",x,{capture:!0}),()=>{document.removeEventListener("keydown",x,{capture:!0}),document.removeEventListener("pointerdown",h,{capture:!0}),document.removeEventListener("pointermove",h,{capture:!0})}},[]),a.jsx(it,{...l,children:a.jsx(At,{scope:t,open:n,onOpenChange:u,content:m,onContentChange:v,children:a.jsx(jt,{scope:t,onClose:s.useCallback(()=>u(!1),[u]),isUsingKeyboardRef:p,dir:f,modal:i,children:o})})})};De.displayName=G;var Ot="MenuAnchor",re=s.forwardRef((e,t)=>{const{__scopeMenu:n,...o}=e,r=W(n);return a.jsx(dt,{...r,...o,ref:t})});re.displayName=Ot;var ae="MenuPortal",[kt,Pe]=D(ae,{forceMount:void 0}),Ie=e=>{const{__scopeMenu:t,forceMount:n,children:o,container:r}=e,c=P(ae,t);return a.jsx(kt,{scope:t,forceMount:n,children:a.jsx(Y,{present:n||c.open,children:a.jsx(lt,{asChild:!0,container:r,children:o})})})};Ie.displayName=ae;var _="MenuContent",[Lt,se]=D(_),Se=s.forwardRef((e,t)=>{const n=Pe(_,e.__scopeMenu),{forceMount:o=n.forceMount,...r}=e,c=P(_,e.__scopeMenu),i=K(_,e.__scopeMenu);return a.jsx(k.Provider,{scope:e.__scopeMenu,children:a.jsx(Y,{present:o||c.open,children:a.jsx(k.Slot,{scope:e.__scopeMenu,children:i.modal?a.jsx(Ft,{...r,ref:t}):a.jsx(Gt,{...r,ref:t})})})})}),Ft=s.forwardRef((e,t)=>{const n=P(_,e.__scopeMenu),o=s.useRef(null),r=F(t,o);return s.useEffect(()=>{const c=o.current;if(c)return pt(c)},[]),a.jsx(ce,{...e,ref:r,trapFocus:n.open,disableOutsidePointerEvents:n.open,disableOutsideScroll:!0,onFocusOutside:M(e.onFocusOutside,c=>c.preventDefault(),{checkForDefaultPrevented:!1}),onDismiss:()=>n.onOpenChange(!1)})}),Gt=s.forwardRef((e,t)=>{const n=P(_,e.__scopeMenu);return a.jsx(ce,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,disableOutsideScroll:!1,onDismiss:()=>n.onOpenChange(!1)})}),Kt=ht("MenuContent.ScrollLock"),ce=s.forwardRef((e,t)=>{const{__scopeMenu:n,loop:o=!1,trapFocus:r,onOpenAutoFocus:c,onCloseAutoFocus:i,disableOutsidePointerEvents:l,onEntryFocus:m,onEscapeKeyDown:v,onPointerDownOutside:p,onFocusOutside:u,onInteractOutside:f,onDismiss:x,disableOutsideScroll:h,...E}=e,I=P(_,n),A=K(_,n),U=W(n),$=Ee(n),le=Nt(n),[tt,pe]=s.useState(null),B=s.useRef(null),nt=F(t,B,I.onContentChange),V=s.useRef(0),z=s.useRef(""),ot=s.useRef(0),J=s.useRef(null),fe=s.useRef("right"),Q=s.useRef(0),rt=h?Mt:s.Fragment,at=h?{as:Kt,allowPinchZoom:!0}:void 0,st=d=>{var N,ve;const w=z.current+d,C=le().filter(R=>!R.disabled),b=document.activeElement,ee=(N=C.find(R=>R.ref.current===b))==null?void 0:N.textValue,te=C.map(R=>R.textValue),me=Jt(te,w,ee),j=(ve=C.find(R=>R.textValue===me))==null?void 0:ve.ref.current;(function R(Me){z.current=Me,window.clearTimeout(V.current),Me!==""&&(V.current=window.setTimeout(()=>R(""),1e3))})(w),j&&setTimeout(()=>j.focus())};s.useEffect(()=>()=>window.clearTimeout(V.current),[]),vt();const S=s.useCallback(d=>{var C,b;return fe.current===((C=J.current)==null?void 0:C.side)&&en(d,(b=J.current)==null?void 0:b.area)},[]);return a.jsx(Lt,{scope:n,searchRef:z,onItemEnter:s.useCallback(d=>{S(d)&&d.preventDefault()},[S]),onItemLeave:s.useCallback(d=>{var w;S(d)||((w=B.current)==null||w.focus(),pe(null))},[S]),onTriggerLeave:s.useCallback(d=>{S(d)&&d.preventDefault()},[S]),pointerGraceTimerRef:ot,onPointerGraceIntentChange:s.useCallback(d=>{J.current=d},[]),children:a.jsx(rt,{...at,children:a.jsx(xt,{asChild:!0,trapped:r,onMountAutoFocus:M(c,d=>{var w;d.preventDefault(),(w=B.current)==null||w.focus({preventScroll:!0})}),onUnmountAutoFocus:i,children:a.jsx(gt,{asChild:!0,disableOutsidePointerEvents:l,onEscapeKeyDown:v,onPointerDownOutside:p,onFocusOutside:u,onInteractOutside:f,onDismiss:x,children:a.jsx(wt,{asChild:!0,...$,dir:A.dir,orientation:"vertical",loop:o,currentTabStopId:tt,onCurrentTabStopIdChange:pe,onEntryFocus:M(m,d=>{A.isUsingKeyboardRef.current||d.preventDefault()}),preventScrollOnEntryFocus:!0,children:a.jsx(_t,{role:"menu","aria-orientation":"vertical","data-state":He(I.open),"data-radix-menu-content":"",dir:A.dir,...U,...E,ref:nt,style:{outline:"none",...E.style},onKeyDown:M(E.onKeyDown,d=>{const C=d.target.closest("[data-radix-menu-content]")===d.currentTarget,b=d.ctrlKey||d.altKey||d.metaKey,ee=d.key.length===1;C&&(d.key==="Tab"&&d.preventDefault(),!b&&ee&&st(d.key));const te=B.current;if(d.target!==te||!Pt.includes(d.key))return;d.preventDefault();const j=le().filter(N=>!N.disabled).map(N=>N.ref.current);be.includes(d.key)&&j.reverse(),qt(j)}),onBlur:M(e.onBlur,d=>{d.currentTarget.contains(d.target)||(window.clearTimeout(V.current),z.current="")}),onPointerMove:M(e.onPointerMove,L(d=>{const w=d.target,C=Q.current!==d.clientX;if(d.currentTarget.contains(w)&&C){const b=d.clientX>Q.current?"right":"left";fe.current=b,Q.current=d.clientX}}))})})})})})})});Se.displayName=_;var Ut="MenuGroup",ue=s.forwardRef((e,t)=>{const{__scopeMenu:n,...o}=e;return a.jsx(T.div,{role:"group",...o,ref:t})});ue.displayName=Ut;var $t="MenuLabel",Ne=s.forwardRef((e,t)=>{const{__scopeMenu:n,...o}=e;return a.jsx(T.div,{...o,ref:t})});Ne.displayName=$t;var H="MenuItem",xe="menu.itemSelect",q=s.forwardRef((e,t)=>{const{disabled:n=!1,onSelect:o,...r}=e,c=s.useRef(null),i=K(H,e.__scopeMenu),l=se(H,e.__scopeMenu),m=F(t,c),v=s.useRef(!1),p=()=>{const u=c.current;if(!n&&u){const f=new CustomEvent(xe,{bubbles:!0,cancelable:!0});u.addEventListener(xe,x=>o==null?void 0:o(x),{once:!0}),mt(u,f),f.defaultPrevented?v.current=!1:i.onClose()}};return a.jsx(Te,{...r,ref:m,disabled:n,onClick:M(e.onClick,p),onPointerDown:u=>{var f;(f=e.onPointerDown)==null||f.call(e,u),v.current=!0},onPointerUp:M(e.onPointerUp,u=>{var f;v.current||(f=u.currentTarget)==null||f.click()}),onKeyDown:M(e.onKeyDown,u=>{const f=l.searchRef.current!=="";n||f&&u.key===" "||ne.includes(u.key)&&(u.currentTarget.click(),u.preventDefault())})})});q.displayName=H;var Te=s.forwardRef((e,t)=>{const{__scopeMenu:n,disabled:o=!1,textValue:r,...c}=e,i=se(H,n),l=Ee(n),m=s.useRef(null),v=F(t,m),[p,u]=s.useState(!1),[f,x]=s.useState("");return s.useEffect(()=>{const h=m.current;h&&x((h.textContent??"").trim())},[c.children]),a.jsx(k.ItemSlot,{scope:n,disabled:o,textValue:r??f,children:a.jsx(ft,{asChild:!0,...l,focusable:!o,children:a.jsx(T.div,{role:"menuitem","data-highlighted":p?"":void 0,"aria-disabled":o||void 0,"data-disabled":o?"":void 0,...c,ref:v,onPointerMove:M(e.onPointerMove,L(h=>{o?i.onItemLeave(h):(i.onItemEnter(h),h.defaultPrevented||h.currentTarget.focus({preventScroll:!0}))})),onPointerLeave:M(e.onPointerLeave,L(h=>i.onItemLeave(h))),onFocus:M(e.onFocus,()=>u(!0)),onBlur:M(e.onBlur,()=>u(!1))})})})}),Bt="MenuCheckboxItem",Ae=s.forwardRef((e,t)=>{const{checked:n=!1,onCheckedChange:o,...r}=e;return a.jsx(Fe,{scope:e.__scopeMenu,checked:n,children:a.jsx(q,{role:"menuitemcheckbox","aria-checked":X(n)?"mixed":n,...r,ref:t,"data-state":de(n),onSelect:M(r.onSelect,()=>o==null?void 0:o(X(n)?!0:!n),{checkForDefaultPrevented:!1})})})});Ae.displayName=Bt;var je="MenuRadioGroup",[Vt,zt]=D(je,{value:void 0,onValueChange:()=>{}}),Oe=s.forwardRef((e,t)=>{const{value:n,onValueChange:o,...r}=e,c=Ce(o);return a.jsx(Vt,{scope:e.__scopeMenu,value:n,onValueChange:c,children:a.jsx(ue,{...r,ref:t})})});Oe.displayName=je;var ke="MenuRadioItem",Le=s.forwardRef((e,t)=>{const{value:n,...o}=e,r=zt(ke,e.__scopeMenu),c=n===r.value;return a.jsx(Fe,{scope:e.__scopeMenu,checked:c,children:a.jsx(q,{role:"menuitemradio","aria-checked":c,...o,ref:t,"data-state":de(c),onSelect:M(o.onSelect,()=>{var i;return(i=r.onValueChange)==null?void 0:i.call(r,n)},{checkForDefaultPrevented:!1})})})});Le.displayName=ke;var ie="MenuItemIndicator",[Fe,Ht]=D(ie,{checked:!1}),Ge=s.forwardRef((e,t)=>{const{__scopeMenu:n,forceMount:o,...r}=e,c=Ht(ie,n);return a.jsx(Y,{present:o||X(c.checked)||c.checked===!0,children:a.jsx(T.span,{...r,ref:t,"data-state":de(c.checked)})})});Ge.displayName=ie;var Xt="MenuSeparator",Ke=s.forwardRef((e,t)=>{const{__scopeMenu:n,...o}=e;return a.jsx(T.div,{role:"separator","aria-orientation":"horizontal",...o,ref:t})});Ke.displayName=Xt;var Yt="MenuArrow",Ue=s.forwardRef((e,t)=>{const{__scopeMenu:n,...o}=e,r=W(n);return a.jsx(Ct,{...r,...o,ref:t})});Ue.displayName=Yt;var Wt="MenuSub",[Jn,$e]=D(Wt),O="MenuSubTrigger",Be=s.forwardRef((e,t)=>{const n=P(O,e.__scopeMenu),o=K(O,e.__scopeMenu),r=$e(O,e.__scopeMenu),c=se(O,e.__scopeMenu),i=s.useRef(null),{pointerGraceTimerRef:l,onPointerGraceIntentChange:m}=c,v={__scopeMenu:e.__scopeMenu},p=s.useCallback(()=>{i.current&&window.clearTimeout(i.current),i.current=null},[]);return s.useEffect(()=>p,[p]),s.useEffect(()=>{const u=l.current;return()=>{window.clearTimeout(u),m(null)}},[l,m]),a.jsx(re,{asChild:!0,...v,children:a.jsx(Te,{id:r.triggerId,"aria-haspopup":"menu","aria-expanded":n.open,"aria-controls":r.contentId,"data-state":He(n.open),...e,ref:Re(t,r.onTriggerChange),onClick:u=>{var f;(f=e.onClick)==null||f.call(e,u),!(e.disabled||u.defaultPrevented)&&(u.currentTarget.focus(),n.open||n.onOpenChange(!0))},onPointerMove:M(e.onPointerMove,L(u=>{c.onItemEnter(u),!u.defaultPrevented&&!e.disabled&&!n.open&&!i.current&&(c.onPointerGraceIntentChange(null),i.current=window.setTimeout(()=>{n.onOpenChange(!0),p()},100))})),onPointerLeave:M(e.onPointerLeave,L(u=>{var x,h;p();const f=(x=n.content)==null?void 0:x.getBoundingClientRect();if(f){const E=(h=n.content)==null?void 0:h.dataset.side,I=E==="right",A=I?-5:5,U=f[I?"left":"right"],$=f[I?"right":"left"];c.onPointerGraceIntentChange({area:[{x:u.clientX+A,y:u.clientY},{x:U,y:f.top},{x:$,y:f.top},{x:$,y:f.bottom},{x:U,y:f.bottom}],side:E}),window.clearTimeout(l.current),l.current=window.setTimeout(()=>c.onPointerGraceIntentChange(null),300)}else{if(c.onTriggerLeave(u),u.defaultPrevented)return;c.onPointerGraceIntentChange(null)}})),onKeyDown:M(e.onKeyDown,u=>{var x;const f=c.searchRef.current!=="";e.disabled||f&&u.key===" "||It[o.dir].includes(u.key)&&(n.onOpenChange(!0),(x=n.content)==null||x.focus(),u.preventDefault())})})})});Be.displayName=O;var Ve="MenuSubContent",ze=s.forwardRef((e,t)=>{const n=Pe(_,e.__scopeMenu),{forceMount:o=n.forceMount,...r}=e,c=P(_,e.__scopeMenu),i=K(_,e.__scopeMenu),l=$e(Ve,e.__scopeMenu),m=s.useRef(null),v=F(t,m);return a.jsx(k.Provider,{scope:e.__scopeMenu,children:a.jsx(Y,{present:o||c.open,children:a.jsx(k.Slot,{scope:e.__scopeMenu,children:a.jsx(ce,{id:l.contentId,"aria-labelledby":l.triggerId,...r,ref:v,align:"start",side:i.dir==="rtl"?"left":"right",disableOutsidePointerEvents:!1,disableOutsideScroll:!1,trapFocus:!1,onOpenAutoFocus:p=>{var u;i.isUsingKeyboardRef.current&&((u=m.current)==null||u.focus()),p.preventDefault()},onCloseAutoFocus:p=>p.preventDefault(),onFocusOutside:M(e.onFocusOutside,p=>{p.target!==l.trigger&&c.onOpenChange(!1)}),onEscapeKeyDown:M(e.onEscapeKeyDown,p=>{i.onClose(),p.preventDefault()}),onKeyDown:M(e.onKeyDown,p=>{var x;const u=p.currentTarget.contains(p.target),f=St[i.dir].includes(p.key);u&&f&&(c.onOpenChange(!1),(x=l.trigger)==null||x.focus(),p.preventDefault())})})})})})});ze.displayName=Ve;function He(e){return e?"open":"closed"}function X(e){return e==="indeterminate"}function de(e){return X(e)?"indeterminate":e?"checked":"unchecked"}function qt(e){const t=document.activeElement;for(const n of e)if(n===t||(n.focus(),document.activeElement!==t))return}function Zt(e,t){return e.map((n,o)=>e[(t+o)%e.length])}function Jt(e,t,n){const r=t.length>1&&Array.from(t).every(v=>v===t[0])?t[0]:t,c=n?e.indexOf(n):-1;let i=Zt(e,Math.max(c,0));r.length===1&&(i=i.filter(v=>v!==n));const m=i.find(v=>v.toLowerCase().startsWith(r.toLowerCase()));return m!==n?m:void 0}function Qt(e,t){const{x:n,y:o}=e;let r=!1;for(let c=0,i=t.length-1;c<t.length;i=c++){const l=t[c],m=t[i],v=l.x,p=l.y,u=m.x,f=m.y;p>o!=f>o&&n<(u-v)*(o-p)/(f-p)+v&&(r=!r)}return r}function en(e,t){if(!t)return!1;const n={x:e.clientX,y:e.clientY};return Qt(n,t)}function L(e){return t=>t.pointerType==="mouse"?e(t):void 0}var tn=De,nn=re,on=Ie,rn=Se,an=ue,sn=Ne,cn=q,un=Ae,dn=Oe,ln=Le,pn=Ge,fn=Ke,mn=Ue,vn=Be,Mn=ze,Z="DropdownMenu",[hn]=ge(Z,[ye]),g=ye(),[xn,Xe]=hn(Z),Ye=e=>{const{__scopeDropdownMenu:t,children:n,dir:o,open:r,defaultOpen:c,onOpenChange:i,modal:l=!0}=e,m=g(t),v=s.useRef(null),[p,u]=Rt({prop:r,defaultProp:c??!1,onChange:i,caller:Z});return a.jsx(xn,{scope:t,triggerId:he(),triggerRef:v,contentId:he(),open:p,onOpenChange:u,onOpenToggle:s.useCallback(()=>u(f=>!f),[u]),modal:l,children:a.jsx(tn,{...m,open:p,onOpenChange:u,dir:o,modal:l,children:n})})};Ye.displayName=Z;var We="DropdownMenuTrigger",qe=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,disabled:o=!1,...r}=e,c=Xe(We,n),i=g(n);return a.jsx(nn,{asChild:!0,...i,children:a.jsx(T.button,{type:"button",id:c.triggerId,"aria-haspopup":"menu","aria-expanded":c.open,"aria-controls":c.open?c.contentId:void 0,"data-state":c.open?"open":"closed","data-disabled":o?"":void 0,disabled:o,...r,ref:Re(t,c.triggerRef),onPointerDown:M(e.onPointerDown,l=>{!o&&l.button===0&&l.ctrlKey===!1&&(c.onOpenToggle(),c.open||l.preventDefault())}),onKeyDown:M(e.onKeyDown,l=>{o||(["Enter"," "].includes(l.key)&&c.onOpenToggle(),l.key==="ArrowDown"&&c.onOpenChange(!0),["Enter"," ","ArrowDown"].includes(l.key)&&l.preventDefault())})})})});qe.displayName=We;var gn="DropdownMenuPortal",Ze=e=>{const{__scopeDropdownMenu:t,...n}=e,o=g(t);return a.jsx(on,{...o,...n})};Ze.displayName=gn;var Je="DropdownMenuContent",Qe=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=Xe(Je,n),c=g(n),i=s.useRef(!1);return a.jsx(rn,{id:r.contentId,"aria-labelledby":r.triggerId,...c,...o,ref:t,onCloseAutoFocus:M(e.onCloseAutoFocus,l=>{var m;i.current||(m=r.triggerRef.current)==null||m.focus(),i.current=!1,l.preventDefault()}),onInteractOutside:M(e.onInteractOutside,l=>{const m=l.detail.originalEvent,v=m.button===0&&m.ctrlKey===!0,p=m.button===2||v;(!r.modal||p)&&(i.current=!0)}),style:{...e.style,"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)","--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)","--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)","--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"}})});Qe.displayName=Je;var wn="DropdownMenuGroup",_n=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(an,{...r,...o,ref:t})});_n.displayName=wn;var Cn="DropdownMenuLabel",Rn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(sn,{...r,...o,ref:t})});Rn.displayName=Cn;var bn="DropdownMenuItem",et=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(cn,{...r,...o,ref:t})});et.displayName=bn;var yn="DropdownMenuCheckboxItem",En=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(un,{...r,...o,ref:t})});En.displayName=yn;var Dn="DropdownMenuRadioGroup",Pn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(dn,{...r,...o,ref:t})});Pn.displayName=Dn;var In="DropdownMenuRadioItem",Sn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(ln,{...r,...o,ref:t})});Sn.displayName=In;var Nn="DropdownMenuItemIndicator",Tn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(pn,{...r,...o,ref:t})});Tn.displayName=Nn;var An="DropdownMenuSeparator",jn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(fn,{...r,...o,ref:t})});jn.displayName=An;var On="DropdownMenuArrow",kn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(mn,{...r,...o,ref:t})});kn.displayName=On;var Ln="DropdownMenuSubTrigger",Fn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(vn,{...r,...o,ref:t})});Fn.displayName=Ln;var Gn="DropdownMenuSubContent",Kn=s.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...o}=e,r=g(n);return a.jsx(Mn,{...r,...o,ref:t,style:{...e.style,"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)","--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)","--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)","--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"}})});Kn.displayName=Gn;var Un=Ye,$n=qe,Bn=Ze,Vn=Qe,zn=et;function Qn({...e}){return a.jsx(Un,{"data-slot":"dropdown-menu",...e})}function eo({...e}){return a.jsx($n,{"data-slot":"dropdown-menu-trigger",...e})}function to({className:e,sideOffset:t=4,...n}){return a.jsx(Bn,{children:a.jsx(Vn,{"data-slot":"dropdown-menu-content",sideOffset:t,className:y("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 max-h-(--radix-dropdown-menu-content-available-height) min-w-[8rem] origin-(--radix-dropdown-menu-content-transform-origin) overflow-x-hidden overflow-y-auto rounded-md border p-1 shadow-md",e),...n})})}function no({className:e,inset:t,variant:n="default",...o}){return a.jsx(zn,{"data-slot":"dropdown-menu-item","data-inset":t,"data-variant":n,className:y("focus:bg-accent focus:text-accent-foreground data-[variant=destructive]:text-destructive data-[variant=destructive]:focus:bg-destructive/10 dark:data-[variant=destructive]:focus:bg-destructive/20 data-[variant=destructive]:focus:text-destructive data-[variant=destructive]:*:[svg]:!text-destructive [&_svg:not([class*='text-'])]:text-muted-foreground relative flex cursor-default items-center gap-2 rounded-sm px-2 py-1.5 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 data-[inset]:pl-8 [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4",e),...o})}function oo({className:e,...t}){return a.jsx("div",{"data-slot":"table-container",className:"relative w-full overflow-x-auto",children:a.jsx("table",{"data-slot":"table",className:y("w-full caption-bottom text-sm",e),...t})})}function ro({className:e,...t}){return a.jsx("thead",{"data-slot":"table-header",className:y("[&_tr]:border-b bg-gray-50",e),...t})}function ao({className:e,...t}){return a.jsx("tbody",{"data-slot":"table-body",className:y("[&_tr:last-child]:border-0",e),...t})}function so({className:e,...t}){return a.jsx("tr",{"data-slot":"table-row",className:y("hover:bg-muted/50 data-[state=selected]:bg-muted border-b transition-colors",e),...t})}function co({className:e,...t}){return a.jsx("th",{"data-slot":"table-head",className:y("text-foreground h-10 px-4 text-left align-middle font-medium whitespace-nowrap [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t})}function uo({className:e,...t}){return a.jsx("td",{"data-slot":"table-cell",className:y("py-2 px-4 align-middle whitespace-nowrap [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t})}export{Qn as D,Wn as E,qn as P,Zn as T,eo as a,to as b,no as c,oo as d,ro as e,so as f,co as g,ao as h,uo as i};
